import Toolbar from '@mui/material/Toolbar'
import AppBar from '@mui/material/AppBar';
import { makeStyles } from '@material-ui/core'
import Button from '@mui/material/Button';
import { useState } from 'react';

import Credentials from './Credentials'
import Buttons from './Buttons'

const useStyles = makeStyles({
  toolBar: {
    color: '#6e6d6d',
    display: 'flex',
    justifyContent: 'space-between',
    backgroundColor: '#ffffff',
    height:'7vh'
  },
  buttonDelete: {
    color: '#f8f8f8',
    backgroundColor:'#1d74c5',
  },
  modalDelete: {
    background: '#ffffff',
    position: 'absolute',
    content:'',
    width: '20%',
    height:'auto',
    left: '40%',
    bottom: '48.5%',
    borderRadius: 10,
    padding: 10,
    display: 'flex',
    flexDirection:'column'
  },  
  overlay: {
    position: 'fixed',
    top: 0,
    left: 0,
    width: '100vw',
    height: '100vh',
    zIndex: 100,
    backgroundColor: 'rgba(104, 105, 104, 0.6)',
    overflowY: 'hidden',
  },  
})

interface IHeaderBar {
  selectedArr: string[] | [],
  isSomeSelected: boolean,
  setIsSomeSelected: React.Dispatch<React.SetStateAction<boolean>>,
  handleClearSelect: () => void
}

const HeaderBar = ({selectedArr,isSomeSelected,setIsSomeSelected,handleClearSelect}:IHeaderBar) => {
  const classes = useStyles()
  const [modal, setModal] = useState<boolean>(false)
  const handleOpenModal = (): void => setModal(true)
  const handleDeleteModal = (e: any) => {
    const id = e.target.id
    if (id === 'overlay') return setModal(false)
    if (id === 'cancel') {
      handleClearSelect()
      setModal(false)
    }
    if (id === 'delete') {
      // fetch on server
      handleClearSelect()
      setModal(false)
    }
  }    

    return (!isSomeSelected?
      <AppBar position="static">
        <Toolbar className={classes.toolBar}>
          <Credentials/>
          <Buttons setIsSomeSelected={setIsSomeSelected}/>
        </Toolbar>
      </AppBar> :
      <AppBar position="static">
        <Toolbar className={classes.toolBar}>
          <Button color='primary' onClick={handleOpenModal}
            variant="contained" className={classes.buttonDelete}
            style={{visibility: selectedArr.length === 0 ? 'hidden' : 'visible',
              fontWeight:500}}>
            {`DELETE ${selectedArr.length}`}
          </Button>
          <Button onClick={handleClearSelect} style={{color:'#1d74c5',fontWeight:500}}>
            CANCEL
          </Button>
        </Toolbar>
        {modal &&
        <div onClick={handleDeleteModal} className={classes.overlay} id='overlay'>
          <div className={classes.modalDelete}>
            <h3 style={{color: '#2c2c2c'}}>Delete messages</h3>
            <p style={{ color: '#050505' }}>Are you sure you want to delete messages?</p>
            <Button id='delete' variant="text" color="error" style={{fontWeight:500,fontSize:22}}>
              DELETE MESSAGES
            </Button>         
            <Button id='cancel' variant="text" style={{fontWeight:500,fontSize:22}}>
               CANCEL
            </Button>
          </div>  
        </div>}         
      </AppBar>      
    )
}

export default HeaderBar

